@@ -69,5 +69,5 @@ HCAA_Portfolio = function(covar, linkage = "ward", graph = FALSE, clusters = NUL
   if (graph) plot(clustering, xlab = "", ylab = "", main = "Cluster Dendrogram - HCAA")
   weights <- data.frame(weights)
   row.names(weights) <- colnames(covar)
-  return(weights)
+  return(list(weights, n_clusters))
 }
